@@ -8,7 +8,7 @@ package Games::RolePlay::MapGen::Editor;
 #
 # -Paul
 
-use strict;
+use common::sense;
 use GD;
 use Glib qw(TRUE FALSE);
 use Gtk2 -init; # -init tells import to ->init() your app
