@@ -2,9 +2,9 @@
 
 package Games::RolePlay::MapGen::Generator::Blank;
 
-use strict;
+use common::sense;
 use Carp;
-use base qw(Games::RolePlay::MapGen::Generator);
+use parent 'Games::RolePlay::MapGen::Generator';
 use Games::RolePlay::MapGen::Tools qw( _tile );
 
 1;
